<?xml version='1.0' ?>
<!-- Licensed Materials - Property of IBM and/or HCL "Restricted Materials of IBM" IBM Informix Dynamic Server Copyright IBM Corporation 2012 (c) Copyright HCL Technologies Ltd. 2017.  All Rights Reserved. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:idsext="xalan://com.ibm.informix.install.IDSXSLExtensions">
	<!-- space control -->
	<xsl:output method="xml" encoding="UTF-8" cdata-section-elements="string" />
	<!-- <xsl:strip-space elements="string"/> -->

	<!-- input parameters -->
	<xsl:param name="machinetype" select="machine" />
	<xsl:param name="major" select="11" />
	<xsl:param name="minor" select="60" />
	<xsl:param name="platform" select="'U'" />
	<xsl:param name="fixpack" select="1" />
	<xsl:param name="installType" select="web" />
	<xsl:param name="long_product" select="ids" />
	<xsl:param name="product" select="ids" />
	<xsl:param name="edition" select="ul" />
	<xsl:param name="vendor" select="IBM" />
	<xsl:variable name="majorProp" select="'major'" />
	<xsl:variable name="minorProp" select="'minor'" />
	<xsl:variable name="revProp" select="'revision'" />
	<xsl:variable name="fpProp" select="'subRevision'" />

	<xsl:template name="ascii2dec">
		<xsl:param name="input" />
		<xsl:choose>
			<xsl:when test="$input = 'B'">
				<xsl:text>66</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'F'">
				<xsl:text>70</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'H'">
				<xsl:text>72</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'J'">
				<xsl:text>74</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'P'">
				<xsl:text>80</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'T'">
				<xsl:text>84</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'U'">
				<xsl:text>85</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'W'">
				<xsl:text>87</xsl:text>
			</xsl:when>
			<xsl:when test="$input = 'X'">
				<xsl:text>88</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>88</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:variable name="platformInt">
		<xsl:call-template name="ascii2dec">
			<xsl:with-param name="input" select="$platform" />
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="javadatamodle">
		<xsl:choose>
			<xsl:when test="contains($machinetype, 'win64_amd')">
				<xsl:text> </xsl:text>
			</xsl:when>
			<xsl:when test="contains($machinetype, 'nt_intel')">
				<xsl:text> </xsl:text>
			</xsl:when>
			<xsl:when test="contains($platform, 'F')">
				<xsl:text>-d64</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>-d32</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="contains($machinetype, 'macosx')">
				<xsl:text> -Xmx512m -Xdock:name=</xsl:text>
				<xsl:value-of select="translate($long_product, ' ', '_')" />
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<!-- Based on the module objectID get the subinstaller objectID -->
	<xsl:template name="lookupSubInstallerID">
		<xsl:param name="moduleID" />
		<xsl:for-each select="//object[@class='com.zerog.ia.installer.actions.Subinstaller']">
			<xsl:if test="property[@name='project']/object[@refID=$moduleID]">
				<xsl:value-of select="@objectID" />
			</xsl:if>
		</xsl:for-each>
		<xsl:for-each select="//object[@class='com.zerog.ia.installer.actions.BuildTimeMergeModule']">
			<xsl:if test="property[@name='project']/object[@objectID=$moduleID] or property[@name='project']/object[@refID=$moduleID]">
				<xsl:value-of select="@objectID" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<!-- based on the merge module zipfile name get the objectID for the mergeModule -->
	<xsl:template name="lookupMergeModuleID">
		<xsl:param name="moduleName" />
		<xsl:for-each select="//object[@class='com.zerog.ia.installer.DynamicMergeModule']">
			<xsl:if test="property[@name='name']/string=$moduleName">
				<xsl:value-of select="@objectID" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="lookupInstallMergeModuleID">
		<xsl:param name="moduleName" />
		<xsl:for-each select="//object[@class='com.zerog.ia.installer.actions.Subinstaller']">
			<xsl:if test="property[@name='resourceName']/string=$moduleName">
				<xsl:value-of select="@objectID" />
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:variable name="CSDKobjectID">
		<xsl:if test="$installType = 'web' and $product = 'ids'">
			<xsl:call-template name="lookupMergeModuleID">
				<xsl:with-param name="moduleName" select="'Client_SDK.iam.zip'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="CONNobjectID">
		<xsl:if test="$installType = 'web' and $product = 'ids'">
			<xsl:call-template name="lookupMergeModuleID">
				<xsl:with-param name="moduleName" select="'Client_Connect.iam.zip'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="JDBCobjectID">
		<xsl:if test="$installType = 'web' and (($product = 'ids') or ($product = 'Bundle' and contains($platform,'macosx')))">
			<xsl:call-template name="lookupMergeModuleID">
				<xsl:with-param name="moduleName" select="'IBM_Informix_JDBC_4.10.iam.zip'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="GLSobjectID">
		<xsl:if test="$installType = 'module'">
			<xsl:call-template name="lookupMergeModuleID">
				<xsl:with-param name="moduleName" select="'Global_Language_Support.iam.zip'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="IBMobjectID">
		<xsl:if test="$installType = 'web' and not(contains($machinetype, 'win64_amd') or contains($machinetype, 'nt_intel'))">
			<xsl:call-template name="lookupInstallMergeModuleID">
				<xsl:with-param name="moduleName" select="'IBM_Informix_Dynamic_Server_BladeManager.iam.zip'" />
			</xsl:call-template>
		</xsl:if>
	</xsl:variable>
	<xsl:variable name="RemoveObjectIDs">
		<xsl:value-of select='$CONNobjectID' />
		<xsl:text> </xsl:text>
		<xsl:value-of select='$CSDKobjectID' />
		<xsl:text> </xsl:text>
		<xsl:value-of select='$JDBCobjectID' />
		<xsl:text> </xsl:text>
		<xsl:value-of select='$GLSobjectID' />
		<xsl:text> </xsl:text>
		<xsl:value-of select='$IBMobjectID' />
		<xsl:text> </xsl:text>
		<xsl:call-template name="lookupSubInstallerID">
			<xsl:with-param name="moduleID" select="$CONNobjectID" />
		</xsl:call-template>
		<xsl:text> </xsl:text>
		<xsl:call-template name="lookupSubInstallerID">
			<xsl:with-param name="moduleID" select="$CSDKobjectID" />
		</xsl:call-template>
		<xsl:text> </xsl:text>
		<xsl:call-template name="lookupSubInstallerID">
			<xsl:with-param name="moduleID" select="$JDBCobjectID" />
		</xsl:call-template>
		<xsl:text> </xsl:text>
		<xsl:call-template name="lookupSubInstallerID">
			<xsl:with-param name="moduleID" select="$GLSobjectID" />
		</xsl:call-template>
		<xsl:text> </xsl:text>
		<!-- prevents false positive Match -->
		<xsl:text> invalid</xsl:text>
	</xsl:variable>

	<!-- copy everything -->
	<xsl:template match="*|@*">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()" />
		</xsl:copy>
	</xsl:template>

	<xsl:template match="object[@class='com.zerog.ia.installer.util.LAXPropertyData']/property[@name='propertyValue']/string">
		<!-- <xsl:value-of select="string"></xsl:value-of> -->
		<xsl:variable name="tmpvalue" select="../../property[@name='propertyName']/string" />
		<xsl:choose>
			<!-- <xsl:when test="contains($platform, 'macos')"> -->
			<xsl:when test="$tmpvalue='lax.nl.java.option.additional' and contains($machinetype, 'macosx')">
				<xsl:element name="string">
					<xsl:value-of select="."></xsl:value-of>
					<xsl:text> -Xdock:name=</xsl:text>
					<xsl:value-of select="translate($long_product, ' ', '_')" />
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:copy-of select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- change the property embed the version of the installer at build time -->
	<xsl:template match="object[@class='com.zerog.ia.installer.util.Version']/property">
		<xsl:choose>
			<xsl:when test="@name=$majorProp">							<!-- find the specified property by name -->
				<xsl:copy>												<!-- copy the property element -->
					<xsl:copy-of select="@*" />						<!-- copy the property name attribute -->
					<xsl:element name="{name(./*[position()=1])}">	<!-- create an element of the correct type -->
						<xsl:value-of select="$major" />			<!-- insert the new value -->
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name=$minorProp">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:value-of select="$minor" />
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name=$revProp">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:value-of select="$platformInt" />
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name=$fpProp">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:value-of select="idsext:FixpackStrToInt($fixpack)" />
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>						<!-- copy all other properties -->
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- albert changes the references in the bundle project from the merge moddule reference to the invob copyout location so that all references can be resolved by the installer -->
	<xsl:template name="albert">
		<xsl:variable name="path">
			<xsl:value-of select="string" />
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@name='resourcePath' and contains($path,'861d707979e6f3cb2ddc620b650ae28a')">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:text>$SOURCE_PATH$</xsl:text>
						<!--<xsl:text>$INSTALL_API$</xsl:text> -->
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name='resourcePath' and contains($path,'860158cd5dbe856b34e0eb84451aae7c')">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:text>$INSTALL_API$</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name='resourcePath' and contains($path,'fc220002c32b63f2552330698f126033')">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:text>$LAP_TOOL$</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name='resourcePath' and contains($path,'44e2ccb988e370a8804ae1af3fe31af9')">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:text>$IA_HOME$/plugins</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.PlugInAction']/property">
		<xsl:call-template name="albert" />
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.CustomAction']/property">
		<xsl:call-template name="albert" />
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.rules.CustomRule']/property">
		<xsl:call-template name="albert" />
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.PlugInConsoleAction']/property">
		<xsl:call-template name="albert" />
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.PlugInPanelAction']/property">
		<xsl:call-template name="albert" />
	</xsl:template>
	<xsl:template match="object[@class='java.util.Properties']/method">
		<xsl:choose>
			<xsl:when test="contains(.,'com.zerog.ia.installer.options.arguments')">
				<xsl:text disable-output-escaping="yes">&lt;method name="put"&gt;&#xA;&lt;string&gt;&lt;![CDATA[com.zerog.ia.installer.options.arguments]]&gt;&lt;/string&gt;&#xA;&lt;string&gt;&lt;![CDATA[</xsl:text>
				<xsl:value-of select="$javadatamodle" />
				<xsl:text disable-output-escaping="yes">]]&gt;&lt;/string&gt;&#xA;&lt;/method&gt;</xsl:text>
			</xsl:when>
			<xsl:otherwise>						<!-- copy all other properties -->
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- this template switches the uninstall from grapical to console launcher -->
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.InstallUninstaller']/property">
		<xsl:choose>
			<xsl:when test="@name='guiLauncher' and not(contains($machinetype, 'win64_amd') or contains($machinetype, 'nt_intel'))">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:element name="{name(./*[position()=1])}">
						<xsl:text>false</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Change the client modules to not have lables -->
	<xsl:template match="object[@class='com.zerog.ia.installer.util.InstallFrameConfigurator']/property">
		<xsl:choose>
			<xsl:when test="@name='decorationType' and $installType = 'module' and $product != 'ids'">
				<!-- non ids installer suppress the left hand side panle in the merge module -->
				<xsl:element name="property">
					<xsl:attribute name="name"><xsl:text>decorationType</xsl:text></xsl:attribute>
					<xsl:text>&#xa;</xsl:text>
					<xsl:text disable-output-escaping="yes">&#x3c;int&#x3e;0&#x3c;/int&#x3e;&#xa;</xsl:text>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- enumerate the lables copied from the IDS merge module -->
	<xsl:template name="outNlemenets">
		<xsl:param name="elem" />
		<xsl:param name="n" />
		<xsl:choose>
			<xsl:when test="$elem &lt; $n">
				<xsl:text>&#xa;</xsl:text>
				<xsl:copy-of select="./*/*[position()=$elem + 1]"></xsl:copy-of>
				<xsl:call-template name="outNlemenets">
					<xsl:with-param name="elem">
						<xsl:value-of select="$elem + 1"></xsl:value-of>
					</xsl:with-param>
					<xsl:with-param name="n">
						<xsl:value-of select="$n"></xsl:value-of>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- copy the lables from the IDS merger module -->
	<xsl:template name="outN">
		<xsl:param name="elem" />
		<xsl:param name="n" />
		<xsl:choose>
			<xsl:when test="$elem &lt; $n">
				<xsl:text>&#xa;</xsl:text>
				<xsl:element name="method">
					<xsl:attribute name="name">addElement</xsl:attribute>
					<xsl:text>&#xa;</xsl:text>
					<xsl:element name="string">
						<xsl:value-of select="$elem" />
					</xsl:element>
					<xsl:text>&#xa;</xsl:text>
				</xsl:element>
				<xsl:call-template name="outN">
					<xsl:with-param name="elem">
						<xsl:value-of select="$elem + 1"></xsl:value-of>
					</xsl:with-param>
					<xsl:with-param name="n">
						<xsl:value-of select="$n"></xsl:value-of>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Remove the lables from the IDS merge module that are not used by the bundle -->
	<xsl:template match="object[@class='com.zerog.ia.installer.Installer']/property">
		<xsl:choose>
			<xsl:when test="@name='installLabels' and $installType = 'module' and $product = 'ids'">
				<!--For the IDS lables output the first three lables in the file -->
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:text>&#xa;</xsl:text>
					<xsl:element name="object">
						<xsl:attribute name="class">java.util.Vector</xsl:attribute>
						<xsl:call-template name="outNlemenets">
							<xsl:with-param name="elem" select="0" />
							<xsl:with-param name="n" select="3" />
						</xsl:call-template>
						<xsl:text>&#xa;</xsl:text>
					</xsl:element>
					<xsl:text>&#xa;</xsl:text>
				</xsl:copy>
			</xsl:when>
			<xsl:when test="@name='installLabelsOrder' and $installType = 'module' and $product = 'ids'">
				<!--For the IDS lables output lable order [0,1,2] -->
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:text>&#xa;</xsl:text>
					<xsl:element name="object">
						<xsl:attribute name="class">java.util.Vector</xsl:attribute>
						<xsl:call-template name="outN">
							<xsl:with-param name="elem" select="0" />
							<xsl:with-param name="n" select="3" />
						</xsl:call-template>
						<xsl:text>&#xa;</xsl:text>
					</xsl:element>
					<xsl:text>&#xa;</xsl:text>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Alter the UI elements so that the bundle selects the IDS merge module lables in the correct order -->
	<xsl:template match="property[@name='labelIndex']/int">
		<xsl:choose>
			<xsl:when test="$installType = 'module' and $product = 'ids'">
				<xsl:choose>
					<!-- pre install second lable 4 displated 5 6 suppressed -->
					<!-- 4 = Server Config -->
					<!-- 5 = Summery -->
					<!-- 6 = installing -->
					<xsl:when test=". = 4 or . = 5 or . = 6">
						<xsl:element name="int">
							<xsl:text>1</xsl:text>
						</xsl:element>
					</xsl:when>
					<!-- post install 7 displayed 8 suppressed -->
					<!-- 7 = Post install steps -->
					<!-- 8 = Summery -->
					<xsl:when test=". = 7 or . = 8">
						<xsl:element name="int">
							<xsl:text>2</xsl:text>
						</xsl:element>
					</xsl:when>
					<xsl:otherwise>
						<!-- pre install first lable 0 1 2 suppressed, 3 is displayed -->
						<!-- 0 = intro -->
						<!-- 1 = Location -->
						<!-- 2 = Install Type -->
						<!-- 3 = Security -->
						<xsl:element name="int">
							<xsl:text>0</xsl:text>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- alter the client products so that the previous lable is always selected -->
	<xsl:template match="property[@name='labelOption']/int">
		<xsl:choose>
			<!--Set the lable from merge module projects to previous lable -->
			<xsl:when test="$installType = 'module' and $product != 'ids'">
				<xsl:element name="int">
					<xsl:text>3</xsl:text>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Secton of code to replace merge module advertized variables (single variable) -->
	<xsl:template name="SubInstallerVariableAtom">
		<xsl:param name="prop" />
		<xsl:param name="type" />
		<xsl:param name="value" />
		<xsl:text>&#xa;</xsl:text>
		<xsl:element name="property">
			<xsl:attribute name="name"><xsl:value-of select='$prop' /></xsl:attribute>
			<xsl:text>&#xa;</xsl:text>
			<xsl:element name="{$type}">
				<xsl:value-of select="normalize-space($value)" />
			</xsl:element>
			<xsl:text>&#xa;</xsl:text>
		</xsl:element>
	</xsl:template>

	<!-- Secton of code to replace merge module advertized variables (all variables) -->
	<xsl:template match="object[@class='com.zerog.ia.installer.util.SubInstallerVariableAtom']">
		<xsl:choose>
			<!--If Setting variable in the super project and comment contains a "Set to $VARIABLE$" set the variable -->
			<!-- no more messing around with setting output variables in the bundle project :-) -->
			<xsl:when test="property[@name='type']=1 and contains(property[@name='comment'],'Set to')">
				<xsl:copy>
					<xsl:copy-of select="@*" />
					<xsl:text>&#xa;</xsl:text>
					<xsl:copy-of select="./*[position()=1]"></xsl:copy-of>
					<xsl:text>&#xa;</xsl:text>
					<xsl:call-template name="SubInstallerVariableAtom">
						<xsl:with-param name="prop" select="'value'" />
						<xsl:with-param name="type" select="'string'" />
						<xsl:with-param name="value">
							<xsl:value-of select="substring-after(property[@name='comment'],'Set to ')" />
						</xsl:with-param>
					</xsl:call-template>
					<xsl:text>&#xa;</xsl:text>
					<xsl:copy-of select="./*[position()=3]"></xsl:copy-of>
					<xsl:text>&#xa;</xsl:text>
					<xsl:copy-of select="./*[position()=4]"></xsl:copy-of>
					<xsl:text>&#xa;</xsl:text>
					<xsl:copy-of select="./*[position()=5]"></xsl:copy-of>
					<xsl:text>&#xa;</xsl:text>
				</xsl:copy>
			</xsl:when>
			<!--/If Setting variable in the super project and comment contains a "Set to $VARIABLE$" set the variable -->
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Switch off web installer -->
	<xsl:template match="object[@class='com.zerog.ia.designer.build.BuildConfiguration']/property">
		<xsl:choose>
			<!-- When building a merge module configure the build script not to build the web installer -->
			<!--IA will ignore the build setting in the build properties file -->
			<xsl:when test="@name='wantWeb' and $installType = 'module'">
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:element name="boolean">
						<xsl:text>false</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*|node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="method[@name='addElement']">
		<xsl:variable name="remove">
			<xsl:for-each select="object">
				<xsl:if test="contains($RemoveObjectIDs, @objectID)">
					<xsl:value-of select="@objectID" />
				</xsl:if>
				<xsl:if test="contains($RemoveObjectIDs, @refID)">
					<xsl:value-of select="@refID" />
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:if test="$remove = ''">
			<xsl:copy>
				<xsl:apply-templates select="@*|node()" />
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<xsl:template match="visualChildren">
		<xsl:variable name="remove">
			<xsl:text>|</xsl:text>
			<xsl:for-each select="object">
				<xsl:if test="contains($RemoveObjectIDs, @objectID)">
					<xsl:value-of select="@objectID" />
				</xsl:if>
				<xsl:if test="contains($RemoveObjectIDs, @refID)">
					<xsl:value-of select="@refID" />
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="dontremove">
			<xsl:text>|</xsl:text>
			<xsl:for-each select="object">
				<xsl:if test="not(contains($RemoveObjectIDs, @objectID))">
					<xsl:value-of select="@objectID" />
				</xsl:if>
				<xsl:if test="not(contains($RemoveObjectIDs, @refID))">
					<xsl:value-of select="@refID" />
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:if test="not(($remove != '|') and ($dontremove = '|'))">
			<xsl:copy>
				<xsl:apply-templates select="@*|node()" />
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<xsl:template name="object">
		<xsl:variable name="remove">
			<xsl:if test="not(@refID = '' and @objectID = '')">
				<xsl:if test="contains($RemoveObjectIDs, @refID)">
					<xsl:value-of select="@refID" />
				</xsl:if>
				<xsl:if test="contains($RemoveObjectIDs, @objectID)">
					<xsl:value-of select="@objectID" />
				</xsl:if>
			</xsl:if>
		</xsl:variable>
		<xsl:if test="$remove = ''">
			<xsl:copy>
				<xsl:apply-templates select="@*|node()" />
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	<xsl:template match="object">
		<xsl:call-template name="object" />
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.Subinstaller']">
		<xsl:choose>
			<xsl:when test="$product = 'ids' and $installType = 'web' and property[@name='resourceName']/string='Dynamic_Server.iam.zip'">
				<xsl:element name="object">
					<xsl:attribute name="class"><xsl:value-of select="@class" /></xsl:attribute>
					<xsl:attribute name="objectID"><xsl:value-of select="@objectID" /></xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='resourcePath'">
								<xsl:element name="property">
									<xsl:attribute name="name"><xsl:value-of select="@name"></xsl:value-of> </xsl:attribute>
									<xsl:element name="string">
										<xsl:text>$BUILD_SOURCE$/ibm_ids_Build_Output/Merge_Modules</xsl:text>
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:when test="$product = 'ids' and $installType = 'web' and property[@name='resourceName']/string='Global_Language_Support.iam.zip'">
				<xsl:element name="object">
					<xsl:attribute name="class"><xsl:value-of select="@class" /></xsl:attribute>
					<xsl:attribute name="objectID"><xsl:value-of select="@objectID" /></xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='resourcePath'">
								<xsl:element name="property">
									<xsl:attribute name="name"><xsl:value-of select="@name"></xsl:value-of> </xsl:attribute>
									<xsl:element name="string">
										<xsl:text>$BUILD_SOURCE$/ibm_gls_Build_Output/Merge_Modules</xsl:text>
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="remove">
					<xsl:for-each select="property[@name='project']/object">
						<xsl:if test="contains($RemoveObjectIDs, @refID)">
							<xsl:value-of select="@refID" />
						</xsl:if>
					</xsl:for-each>
					<xsl:if test="contains($RemoveObjectIDs, @objectID)">
						<xsl:value-of select="@objectID" />
					</xsl:if>
				</xsl:variable>
				<xsl:if test="$remove = ''">
					<xsl:copy>
						<xsl:apply-templates select="@*|node()" />
					</xsl:copy>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.DynamicMergeModule']">
		<xsl:choose>
			<xsl:when test="$product = 'ids' and property[@name='name']/string='Dynamic_Server.iam.zip'">
				<xsl:element name="object">
					<xsl:attribute name="class"><xsl:value-of select="@class" /></xsl:attribute>
					<xsl:attribute name="objectID"><xsl:value-of select="@objectID" /></xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='projectLocation'">
								<xsl:element name="property">
									<xsl:attribute name="name"><xsl:value-of select="@name"></xsl:value-of> </xsl:attribute>
									<xsl:element name="string">
										<xsl:text>$BUILD_SOURCE$/ibm_ids_Build_Output/Merge_Modules/Dynamic_Server.iam.zip</xsl:text>
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:when test="$product = 'ids' and property[@name='name']/string='Global_Language_Support.iam.zip'">
				<xsl:element name="object">
					<xsl:attribute name="class"><xsl:value-of select="@class" /></xsl:attribute>
					<xsl:attribute name="objectID"><xsl:value-of select="@objectID" /></xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='projectLocation'">
								<xsl:element name="property">
									<xsl:attribute name="name"><xsl:value-of select="@name"></xsl:value-of> </xsl:attribute>
									<xsl:element name="string">
										<xsl:text>$BUILD_SOURCE$/ibm_gls_Build_Output/Merge_Modules/Global_Language_Support.iam.zip</xsl:text>
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="remove">
					<xsl:for-each select="property[@name='project']/object">
						<xsl:if test="contains($RemoveObjectIDs, @refID)">
							<xsl:value-of select="@refID" />
						</xsl:if>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="$remove = ''">
					<xsl:copy>
						<xsl:apply-templates select="@*|node()" />
					</xsl:copy>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.EditVariableTable']">
		<xsl:choose>
			<xsl:when test="property[@name='name']/string = '$XFORM_PLATFORM$'">
				<xsl:element name="object">
					<xsl:attribute name="class">
						<xsl:value-of select="@class" />
					</xsl:attribute>
					<xsl:attribute name="objectID">
						<xsl:value-of select="@objectID" />
					</xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='value'">
								<xsl:element name="property">
									<xsl:attribute name="name">
										<xsl:value-of select="@name" />
									</xsl:attribute>
									<xsl:element name="string">
										<xsl:value-of select="$machinetype" />
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:when test="property[@name='name']/string = '$LONG_EDITION$'">
				<xsl:element name="object">
					<xsl:attribute name="class">
						<xsl:value-of select="@class" />
					</xsl:attribute>
					<xsl:attribute name="objectID">
						<xsl:value-of select="@objectID" />
					</xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='value'">
								<xsl:element name="property">
									<xsl:attribute name="name">
										<xsl:value-of select="@name" />
									</xsl:attribute>
									<xsl:element name="string">
										<xsl:value-of select="$edition" />
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:when test="$product != 'Bundle' and property[@name='name']/string = '$PRODUCT_TYPE$'">
				<xsl:element name="object">
					<xsl:attribute name="class">
						<xsl:value-of select="@class" />
					</xsl:attribute>
					<xsl:attribute name="objectID">
						<xsl:value-of select="@objectID" />
					</xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='value'">
								<xsl:element name="property">
									<xsl:attribute name="name">
										<xsl:value-of select="@name" />
									</xsl:attribute>
									<xsl:element name="string">
										<xsl:value-of select="$product" />
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:when test="property[@name='name']/string = '$FULL_BUILD_VERSION$'">
				<xsl:element name="object">
					<xsl:attribute name="class">
						<xsl:value-of select="@class" />
					</xsl:attribute>
					<xsl:attribute name="objectID">
						<xsl:value-of select="@objectID" />
					</xsl:attribute>
					<xsl:for-each select="property">
						<xsl:choose>
							<xsl:when test="@name='value'">
								<xsl:element name="property">
									<xsl:attribute name="name">
										<xsl:value-of select="@name" />
									</xsl:attribute>
									<xsl:element name="string">
										<xsl:value-of select="$major" />
										<xsl:text>.</xsl:text>
										<xsl:value-of select="$minor" />
										<xsl:text>.</xsl:text>
										<xsl:value-of select="$platform" />
										<xsl:value-of select="$fixpack" />
									</xsl:element>
								</xsl:element>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy>
									<xsl:apply-templates select="@*|node()" />
								</xsl:copy>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="object" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- remove LAP_SilentLicenseAccepted_IARule -->
	<xsl:template match="object[@class='com.zerog.ia.installer.rules.CustomRule']">
		<xsl:choose>
			<xsl:when test="$vendor = 'HCL' and property[@name='clientClassFullName']/string = 'com.ibm.lex.lap.ia.LAP_SilentLicenseAccepted_IARule'"/>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="object[@class='com.zerog.ia.installer.rules.CompareVariable']">
		<xsl:choose>
			<xsl:when test="$vendor = 'HCL' and property[@name='ruleId']/string = 'CIAV77'"/>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- remove LAP_SilentLicenseAccepted_IARule part 2 -->
	<xsl:template match="object[@class='com.zerog.ia.installer.Installer']/property[@name='ruleExpression']">
		<xsl:choose>
			<xsl:when test="$vendor = 'HCL'">
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:element name="string">
						<xsl:text>ECR128</xsl:text>
					</xsl:element>
				</xsl:copy>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- remove ibm license files, pannel and install action. -->
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.ActionGroup']">
		<xsl:choose>
			<xsl:when test="$vendor = 'HCL' and property[@name='groupName']/string = 'IBM Standard License Agreement'"/>
			<xsl:when test="$vendor != 'HCL' and property[@name='groupName']/string = 'HCL Standard License Agreement'"/>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:variable name="lookupIBMLF">
		<xsl:for-each select="//object[@class='com.zerog.ia.installer.actions.ActionGroup']">
			<xsl:if test="property[@name='groupName']/string='IBM Standard License Agreement'">
			<!--
				<xsl:value-of select="@objectID" />
			-->
				<xsl:for-each select="visualChildren/object">
					<xsl:value-of select="@refID" />
					<xsl:text> </xsl:text>
				</xsl:for-each>
			</xsl:if>
		</xsl:for-each>
	</xsl:variable>
	<xsl:template match="object[@class='com.zerog.ia.installer.actions.InstallFile']">
		<xsl:choose>
			<xsl:when test="$vendor = 'HCL' and contains($RemoveObjectIDs, @objectID)"/>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--Do not install bundled jre for merge modules -->
	<xsl:template match="property[@name='bundledJREInstall']/int">
		<xsl:choose>
			<xsl:when test="$installType = 'module' and $product != 'Bundle'">
				<xsl:element name="int">
					<xsl:text>4</xsl:text>
				</xsl:element>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy>
					<xsl:apply-templates select="@*" />
					<xsl:apply-templates select="node()" />
				</xsl:copy>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
